@@ -58,6 +58,63 @@ class SimpleTests(fin.testing.TestCase):
         a["b"]["c"].append(1)
         self.assertEqual(cache.count(a), 1)
 
+    def test_doc_inheritance(self):
+        class Foo(object):
+
+            @fin.cache.method
+            def meth(self, data):
+                "a method"
+                pass
+
+            @fin.cache.property
+            def prop(self):
+                "a property"
+                pass
+
+        self.assertEqual(Foo.meth.__doc__, "a method")
+        self.assertEqual(Foo().meth.__doc__, "a method")
+        self.assertEqual(Foo.prop.__doc__, "a property")
+
+    def test_getting_classattr(self):
+        class Counter(object):
+            def __init__(self):
+                self.counter = itertools.count()
+
+            @fin.cache.property
+            def count(self, data):
+                return self.counter.next()
+
+        ob = Counter.count
+        assert isinstance(ob, fin.cache.property)
+
+    def test_resetting(self):
+        class Counter(object):
+            def __init__(self):
+                self.counter = itertools.count()
+
+            @fin.cache.method
+            def do_count(self):
+                return self.counter.next()
+
+            @fin.cache.property
+            def count(self):
+                return self.counter.next()
+
+        cache = Counter()
+        self.assertEqual(cache.count, 0)
+        self.assertEqual(cache.count, 0)
+        self.assertEqual(cache.do_count(), 1)
+        self.assertEqual(cache.do_count(), 1)
+        cache.count = None
+        self.assertEqual(cache.count, 2)
+        self.assertEqual(cache.count, 2)
+        cache.do_count.reset(cache)
+        self.assertEqual(cache.do_count(), 3)
+        self.assertEqual(cache.do_count(), 3)
+        Counter.count.reset(cache)
+        self.assertEqual(cache.count, 4)
+
+
     def test_depends(self):
         class Counter(object):
             def __init__(self):
